(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 11.2' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       158,          7]
NotebookDataLength[     73279,       1672]
NotebookOptionsPosition[     72525,       1645]
NotebookOutlinePosition[     72913,       1662]
CellTagsIndexPosition[     72870,       1659]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["Dynamics on the Clebsch Surface (wmg/ajeet 7 February 2019)", "Title",
 CellChangeTimes->{{3.75051356608363*^9, 3.750513587662821*^9}, {
  3.7525174644591923`*^9, 3.7525174782164497`*^9}, {3.7585675352806177`*^9, 
  3.7585675495908422`*^9}},ExpressionUUID->"475d4fe8-64d7-41bc-9fa7-\
34e4277a5789"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"SetDirectory", "[", 
   RowBox[{"NotebookDirectory", "[", "]"}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Quiet", "[", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"<<", " ", "PrecomputedVisuals//Plucker//Plucker27Lines.m"}], ";",
     "\[IndentingNewLine]", 
    RowBox[{"<<", " ", "PrecomputedVisuals//Plucker//PluckerToolbox.m"}], ";",
     "\[IndentingNewLine]", 
    RowBox[{
    "<<", " ", "PrecomputedVisuals//Plucker//PluckerVisualization.m"}], ";", 
    "\[IndentingNewLine]", 
    RowBox[{"<<", " ", "../Toolboxes//DynamicsToolbox.m"}], ";", 
    "\[IndentingNewLine]", 
    RowBox[{"<<", " ", "../Toolboxes//Utilities.m"}], ";"}], "]"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"MyCubic", "=", 
   RowBox[{"Import", "[", "\"\<PrecomputedVisuals//MyCubic.mx\>\"", "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"MyCubicColoredLines", "=", 
   RowBox[{
   "Import", "[", "\"\<PrecomputedVisuals//MyCubicColoredLines.mx\>\"", 
    "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"{", 
    RowBox[{
    "KappaMin", ",", "KappaMax", ",", "StepSize", ",", " ", "CubicPlotRange", 
     ",", "CubicShadowPlotRange"}], "}"}], "=", 
   RowBox[{"Import", "[", "\"\<PrecomputedVisuals//KappaInfo.mx\>\"", "]"}]}],
   ";"}]}], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.742039999418344*^9, 3.74204001617358*^9}, {
   3.742040053268467*^9, 3.742040233802308*^9}, 3.74204041037467*^9, {
   3.742047605036787*^9, 3.742047611334736*^9}, 3.742053013849739*^9, {
   3.742078379750197*^9, 3.742078390918569*^9}, {3.75051361792984*^9, 
   3.7505136222865267`*^9}, {3.750513683510961*^9, 3.750513683924851*^9}, 
   3.750519868881177*^9, {3.7505206982321453`*^9, 3.750520724052554*^9}, {
   3.756477484273233*^9, 3.756477486341118*^9}, {3.75647752430156*^9, 
   3.756477526395602*^9}, {3.7593192393002367`*^9, 
   3.759319242576367*^9}},ExpressionUUID->"63976467-8147-4ef7-ae67-\
2bef6fd50011"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", 
   RowBox[{"**", "**", "FUNCTIONS"}], "*****)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"NewLineFormatter", "[", "string_", "]"}], ":=", 
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"StringLength", "[", "string", "]"}], "\[LessEqual]", "50"}], 
       ",", "string", ",", 
       RowBox[{
        RowBox[{"StringTake", "[", 
         RowBox[{"string", ",", "50"}], "]"}], "<>", "\"\<\\n\>\"", "<>", 
        RowBox[{"NewLineFormatter", "[", 
         RowBox[{"StringTake", "[", 
          RowBox[{"string", ",", 
           RowBox[{"{", 
            RowBox[{"51", ",", 
             RowBox[{"StringLength", "[", "string", "]"}]}], "}"}]}], "]"}], 
         "]"}]}]}], "]"}]}], ";"}], 
   RowBox[{"(*", 
    RowBox[{
     RowBox[{"**", "**", "LINE"}], " ", "COLORS"}], " ", "*****)"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"fileToLoadDyn", "=", "\"\<No File Selected\>\""}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"xyzColoring", "=", 
     RowBox[{"Flatten", "[", 
      RowBox[{"Map", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"Table", "[", 
          RowBox[{"#", ",", 
           RowBox[{"{", 
            RowBox[{"k", ",", "1", ",", "8"}], "}"}]}], "]"}], "&"}], ",", 
        RowBox[{"{", 
         RowBox[{"Red", ",", "Blue", ",", "Green"}], "}"}]}], "]"}], "]"}]}], 
    ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"CLinesSchlafiColoring", "=", 
     RowBox[{"{", 
      RowBox[{
      "Yellow", ",", "Yellow", ",", "Yellow", ",", "Yellow", ",", "Magenta", 
       ",", "Cyan", ",", "Magenta", ",", "Cyan", ",", "Yellow", ",", "Yellow",
        ",", "Yellow", ",", "Yellow", ",", "Magenta", ",", "Cyan", ",", 
       "Magenta", ",", "Cyan", ",", "Yellow", ",", "Yellow", ",", "Yellow", 
       ",", "Yellow", ",", "Magenta", ",", "Cyan", ",", "Magenta", ",", 
       "Cyan"}], "}"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{
     RowBox[{"**", "**", " ", "ECKHARDT"}], " ", "POINTS"}], " ", "*****)"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"EckhardtPoints", "[", "zoom_", "]"}], ":=", 
     RowBox[{"{", 
      RowBox[{"Cyan", ",", 
       RowBox[{"Sphere", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "2"}], ",", 
             RowBox[{"-", "2"}], ",", 
             RowBox[{"-", "2"}]}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "2"}], ",", "2", ",", "2"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"2", ",", " ", "2", ",", " ", 
             RowBox[{"-", "2"}]}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"2", ",", " ", 
             RowBox[{"-", "2"}], ",", " ", "2"}], "}"}]}], "}"}], ",", 
         RowBox[{"0.6", "*", "zoom"}]}], "]"}]}], "}"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{
     RowBox[{"**", "**", " ", "TOGGLER"}], " ", "BAR", " ", "CONTROLS"}], " ",
     "*****)"}], "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{
     RowBox[{"Instructions", ":", " ", 
      RowBox[{
      "TogglerBar", " ", "lets", " ", "you", " ", "edit", " ", "the", " ", 
       "list", " ", "LinesOn", " ", 
       RowBox[{"easily", ".", " ", "When"}], " ", "you", " ", "click", " ", 
       "a", " ", "button"}]}], ",", " ", 
     RowBox[{
     "it", " ", "Joins", " ", "a", " ", "list", " ", "to", " ", "LinesOn"}], 
     ",", " ", 
     RowBox[{
      RowBox[{"and", " ", "if", " ", "you", " ", "un"}], "-", 
      RowBox[{"click", " ", "it"}]}], ",", " ", 
     RowBox[{
     "it", " ", "will", " ", "remove", " ", "that", " ", "list", " ", "from", 
      " ", 
      RowBox[{"LinesOn", ".", " ", "The"}], " ", "list", " ", "of", " ", "24",
       " ", "lines", " ", "is", " ", "hit", " ", "with", " ", "the", " ", 
      "subset", " ", 
      RowBox[{"operation", " ", "[", 
       RowBox[{"[", "LinesOn", "]"}], "]"}]}], ",", " ", 
     RowBox[{"and", " ", "just", " ", "selects", " ", "waht", " ", "you", " ", 
      RowBox[{"want", ".", "\[IndentingNewLine]", "LinesOn"}], " ", 
      "defaults", " ", "to", " ", 
      RowBox[{"Range", "[", "24", "]"}]}], ",", " ", 
     RowBox[{"which", " ", "then", " ", "means", " ", 
      RowBox[{"All24Lines", "[", 
       RowBox[{"[", 
        RowBox[{"Range", "[", "24", "]"}], "]"}], "]"}], " ", "will", " ", 
      "grab", " ", "you", " ", "all", " ", "of", " ", 
      RowBox[{"them", ".", "\[IndentingNewLine]", "So"}]}], ",", " ", 
     RowBox[{"for", " ", "example"}], ",", " ", 
     RowBox[{
     "if", " ", "you", " ", "want", " ", "an", " ", "option", " ", "that", 
      " ", "just", " ", "selects", " ", "the", " ", "first", " ", "5", " ", 
      "lines"}], ",", " ", 
     RowBox[{
      RowBox[{
      "you", " ", "add", " ", "to", " ", "the", " ", "TogglerBar", " ", 
       "list", " ", 
       RowBox[{"{", 
        RowBox[{"1", ",", "2", ",", "3", ",", "4", ",", "5"}], "}"}]}], 
      "\[Rule]", "\"\<First Five\>\""}]}], " ", "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"LinesOn", "=", 
     RowBox[{"{", 
      RowBox[{"Range", "[", "24", "]"}], "}"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{
     RowBox[{"**", "**", " ", "LINES"}], " ", "AND", " ", "INTERSECTIONS"}], 
    " ", "*****)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"NumberOfPencils", "=", 
     RowBox[{
      RowBox[{"Round", "[", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"KappaMax", "-", "KappaMin"}], ")"}], "/", "StepSize"}], 
        ")"}], "]"}], "+", "1"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"TwoPointsAll24Lines", "=", 
     RowBox[{"Range", "[", "NumberOfPencils", "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Intersections", "=", 
     RowBox[{"Range", "[", "NumberOfPencils", "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"For", "[", 
     RowBox[{
      RowBox[{"i", "=", "1"}], ",", 
      RowBox[{"i", "\[LessEqual]", " ", "NumberOfPencils"}], ",", 
      RowBox[{"i", "+=", "1"}], ",", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"k", "=", 
        RowBox[{"KappaMin", "+", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"i", "-", "1"}], ")"}], "*", "StepSize"}]}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{"k", "\[GreaterEqual]", "2"}], ",", "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"All24Lines", "=", 
           RowBox[{"Join", "[", 
            RowBox[{
             RowBox[{"PLinesZ", "[", "k", "]"}], ",", 
             RowBox[{"CLinesZ", "[", "k", "]"}], ",", 
             RowBox[{"PLinesY", "[", "k", "]"}], ",", 
             RowBox[{"CLinesY", "[", "k", "]"}], ",", 
             RowBox[{"PLinesX", "[", "k", "]"}], ",", 
             RowBox[{"CLinesX", "[", "k", "]"}]}], "]"}]}], ";", 
          "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"TwoPointsAll24Lines", "[", 
            RowBox[{"[", "i", "]"}], "]"}], "=", 
           RowBox[{"Map", "[", 
            RowBox[{
             RowBox[{
              RowBox[{"ExtendLineEndPoints", "[", 
               RowBox[{
                RowBox[{
                "PluckerLineToTwoPointsInAffinePatch", "[", "#", "]"}], ",", 
                RowBox[{"2", "*", "CubicPlotRange"}]}], "]"}], "&"}], ",", 
             "All24Lines"}], "]"}]}], ";", "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"Intersections", "[", 
            RowBox[{"[", "i", "]"}], "]"}], "=", "\[IndentingNewLine]", 
           RowBox[{"Table", "[", "\[IndentingNewLine]", 
            RowBox[{
             RowBox[{"If", "[", 
              RowBox[{
               RowBox[{"SkewQ", "[", 
                RowBox[{
                 RowBox[{"All24Lines", "[", 
                  RowBox[{"[", "l1", "]"}], "]"}], ",", " ", 
                 RowBox[{"All24Lines", "[", 
                  RowBox[{"[", "l2", "]"}], "]"}]}], "]"}], ",", 
               "\[IndentingNewLine]", 
               RowBox[{"{", "}"}], ",", "\[IndentingNewLine]", 
               RowBox[{"IntersectionPointInAffinePatch", "[", 
                RowBox[{
                 RowBox[{"All24Lines", "[", 
                  RowBox[{"[", "l1", "]"}], "]"}], ",", 
                 RowBox[{"All24Lines", "[", 
                  RowBox[{"[", "l2", "]"}], "]"}]}], "]"}]}], "]"}], ",", 
             "\[IndentingNewLine]", 
             RowBox[{"{", 
              RowBox[{"l1", ",", 
               RowBox[{"Range", "[", "24", "]"}]}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{"l2", ",", " ", 
               RowBox[{"Range", "[", "24", "]"}]}], "}"}]}], "]"}]}], ";"}]}],
         "\[IndentingNewLine]", "]"}], ";"}]}], "\[IndentingNewLine]", "]"}], 
    ";"}], "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{
     RowBox[{"**", "**", " ", "START"}], " ", "OF", " ", "MANIPULATE", " ", 
     "BLOCK"}], " ", "*****)"}], "\[IndentingNewLine]", 
   RowBox[{"Manipulate", "[", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
      RowBox[{"iter", "=", 
       RowBox[{
        RowBox[{"Round", "[", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"k", "-", "KappaMin"}], ")"}], "/", "StepSize"}], "]"}], 
        "+", "1"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"MyStuffToShow", "=", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"Opacity", "[", "MyCubicOpacity", "]"}], ",", 
         RowBox[{"MyCubic", "[", 
          RowBox[{"[", "iter", "]"}], "]"}]}], "}"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{"k", "\[GreaterEqual]", "2"}], ",", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"LinesOnFiltered", "=", 
          RowBox[{"DeleteDuplicates", "[", 
           RowBox[{"Flatten", "[", "LinesOn", "]"}], "]"}]}], ";", 
         "\[IndentingNewLine]", 
         RowBox[{"(*", 
          RowBox[{
           RowBox[{"**", "**", " ", "CREATING"}], " ", "THE", " ", "TUBE", 
           " ", "OBJECTS", " ", "FOR", " ", "THE", " ", "LINES"}], " ", 
          "*****)"}], "\[IndentingNewLine]", 
         RowBox[{"TubeWidth", "=", 
          RowBox[{"0.17", "*", "Zoom"}]}], ";", "\[IndentingNewLine]", 
         RowBox[{"GraphicsAll24LinesUncolored", "=", 
          RowBox[{"Map", "[", 
           RowBox[{
            RowBox[{
             RowBox[{"{", 
              RowBox[{"Tube", "[", 
               RowBox[{"#", ",", "TubeWidth"}], "]"}], "}"}], "&"}], ",", 
            RowBox[{
             RowBox[{"TwoPointsAll24Lines", "[", 
              RowBox[{"[", "iter", "]"}], "]"}], "[", 
             RowBox[{"[", 
              RowBox[{"Range", "[", "24", "]"}], "]"}], "]"}]}], "]"}]}], ";",
          "\[IndentingNewLine]", 
         RowBox[{"GraphicsAll24Lines", "=", 
          RowBox[{"Partition", "[", 
           RowBox[{
            RowBox[{"Riffle", "[", 
             RowBox[{"lineColoring", ",", "GraphicsAll24LinesUncolored"}], 
             "]"}], ",", "2"}], "]"}]}], ";", "\[IndentingNewLine]", 
         RowBox[{"(*", 
          RowBox[{
           RowBox[{"**", "**", " ", "SHOW"}], " ", "INTERSECTIONS", " ", 
           "CONIDTIONAL"}], " ", "*****)"}], "\[IndentingNewLine]", 
         RowBox[{"Switch", "[", 
          RowBox[{
          "ShowIntersectionsQ", ",", "3", ",", "\[IndentingNewLine]", 
           RowBox[{
            RowBox[{"MyStuffToShow", "=", 
             RowBox[{"{", "\[IndentingNewLine]", 
              RowBox[{
               RowBox[{"{", 
                RowBox[{
                 RowBox[{"Opacity", "[", "MyCubicOpacity", "]"}], ",", 
                 RowBox[{"MyCubic", "[", 
                  RowBox[{"[", "iter", "]"}], "]"}]}], "}"}], ",", " ", 
               "\[IndentingNewLine]", 
               RowBox[{
                RowBox[{"(", "GraphicsAll24Lines", ")"}], "[", 
                RowBox[{"[", "LinesOnFiltered", "]"}], "]"}], ",", 
               "\[IndentingNewLine]", 
               RowBox[{"{", 
                RowBox[{"{", 
                 RowBox[{"White", ",", 
                  RowBox[{"Sphere", "[", 
                   RowBox[{
                    RowBox[{"DeleteCases", "[", 
                    RowBox[{
                    RowBox[{"Flatten", "[", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{"Intersections", "[", 
                    RowBox[{"[", "iter", "]"}], "]"}], ")"}], "[", 
                    RowBox[{"[", 
                    RowBox[{"LinesOnFiltered", ",", "LinesOnFiltered"}], 
                    "]"}], "]"}], ",", "1"}], "]"}], ",", 
                    RowBox[{"{", "}"}]}], "]"}], ",", 
                    RowBox[{"0.6", "*", "Zoom"}]}], "]"}]}], "}"}], "}"}], 
               ",", "\[IndentingNewLine]", 
               RowBox[{"If", "[", 
                RowBox[{
                 RowBox[{"k", "\[Equal]", "18"}], ",", 
                 RowBox[{"EckhardtPoints", "[", "Zoom", "]"}], ",", 
                 RowBox[{"{", "}"}]}], "]"}]}], "}"}]}], ";"}], ",", 
           "\[IndentingNewLine]", "2", ",", "\[IndentingNewLine]", 
           RowBox[{"MyStuffToShow", "=", 
            RowBox[{"{", "\[IndentingNewLine]", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{
                RowBox[{"Opacity", "[", "MyCubicOpacity", "]"}], ",", 
                RowBox[{"MyCubic", "[", 
                 RowBox[{"[", "iter", "]"}], "]"}]}], "}"}], ",", " ", 
              "\[IndentingNewLine]", 
              RowBox[{
               RowBox[{"(", "GraphicsAll24Lines", ")"}], "[", 
               RowBox[{"[", "LinesOnFiltered", "]"}], "]"}], ",", 
              "\[IndentingNewLine]", 
              RowBox[{"{", 
               RowBox[{"{", 
                RowBox[{"White", ",", 
                 RowBox[{"Sphere", "[", 
                  RowBox[{
                   RowBox[{"DeleteCases", "[", 
                    RowBox[{
                    RowBox[{"Flatten", "[", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{"Intersections", "[", 
                    RowBox[{"[", "iter", "]"}], "]"}], ")"}], "[", 
                    RowBox[{"[", 
                    RowBox[{"LinesOnFiltered", ",", "LinesOnFiltered"}], 
                    "]"}], "]"}], ",", "1"}], "]"}], ",", 
                    RowBox[{"{", "}"}]}], "]"}], ",", 
                   RowBox[{"0.6", "*", "Zoom"}]}], "]"}]}], "}"}], "}"}]}], 
             "}"}]}], ",", "\[IndentingNewLine]", "1", ",", 
           "\[IndentingNewLine]", 
           RowBox[{
            RowBox[{"MyStuffToShow", "=", 
             RowBox[{"{", "\[IndentingNewLine]", 
              RowBox[{
               RowBox[{"{", 
                RowBox[{
                 RowBox[{"Opacity", "[", "MyCubicOpacity", "]"}], ",", 
                 RowBox[{"MyCubic", "[", 
                  RowBox[{"[", "iter", "]"}], "]"}]}], "}"}], ",", " ", 
               "\[IndentingNewLine]", 
               RowBox[{
                RowBox[{"(", "GraphicsAll24Lines", ")"}], "[", 
                RowBox[{"[", "LinesOnFiltered", "]"}], "]"}], ",", 
               RowBox[{"If", "[", 
                RowBox[{
                 RowBox[{"k", "\[Equal]", "18"}], ",", 
                 RowBox[{"EckhardtPoints", "[", "Zoom", "]"}], ",", 
                 RowBox[{"{", "}"}]}], "]"}]}], "}"}]}], ";"}], ",", 
           "\[IndentingNewLine]", "0", " ", ",", "\[IndentingNewLine]", 
           RowBox[{
            RowBox[{"MyStuffToShow", "=", 
             RowBox[{"{", "\[IndentingNewLine]", 
              RowBox[{
               RowBox[{"{", 
                RowBox[{
                 RowBox[{"Opacity", "[", "MyCubicOpacity", "]"}], ",", 
                 RowBox[{"MyCubic", "[", 
                  RowBox[{"[", "iter", "]"}], "]"}]}], "}"}], ",", " ", 
               "\[IndentingNewLine]", 
               RowBox[{
                RowBox[{"(", "GraphicsAll24Lines", ")"}], "[", 
                RowBox[{"[", "LinesOnFiltered", "]"}], "]"}]}], "}"}]}], 
            ";"}]}], "\[IndentingNewLine]", "]"}], ";"}]}], 
       "\[IndentingNewLine]", "]"}], ";", "\[IndentingNewLine]", 
      RowBox[{"(*", 
       RowBox[{
        RowBox[{"**", "**", " ", "ONE"}], " ", "OCTANT", " ", "RESTRICTION"}],
        " ", "*****)"}], "\[IndentingNewLine]", 
      RowBox[{"ZMin", "=", 
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{"k", "<", 
          RowBox[{"-", "2"}]}], ",", "0", ",", 
         RowBox[{"Sqrt", "[", 
          RowBox[{"k", "+", "2"}], "]"}]}], "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"exportMe", "=", 
       RowBox[{"Graphics3D", "[", 
        RowBox[{
         RowBox[{"{", "MyStuffToShow", "}"}], ",", 
         RowBox[{"PlotRange", "\[Rule]", 
          RowBox[{"If", "[", 
           RowBox[{"RestrictPositiveQ", ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{"0", ",", 
                RowBox[{"CubicPlotRange", "*", "Zoom"}]}], "}"}], ",", 
              RowBox[{"{", 
               RowBox[{"0", ",", 
                RowBox[{"CubicPlotRange", "*", "Zoom"}]}], "}"}], ",", 
              RowBox[{"{", 
               RowBox[{
                RowBox[{"-", "ZMin"}], ",", 
                RowBox[{"CubicPlotRange", "*", "Zoom"}]}], "}"}]}], "}"}], 
            ",", 
            RowBox[{"CubicPlotRange", "*", "Zoom"}]}], "]"}]}], ",", 
         RowBox[{"ImageSize", "\[Rule]", "500"}], ",", " ", 
         RowBox[{"Boxed", "\[Rule]", "ShowBoxQ"}], ",", 
         RowBox[{"Axes", "\[Rule]", "ShowBoxQ"}], ",", 
         RowBox[{"AxesLabel", "\[Rule]", 
          RowBox[{"{", 
           RowBox[{"\"\<x\>\"", ",", "\"\<y\>\"", ",", "\"\<z\>\""}], "}"}]}],
          ",", 
         RowBox[{"ViewPoint", "\[Rule]", 
          RowBox[{"{", 
           RowBox[{"viewX", ",", "viewY", ",", "viewZ"}], "}"}]}]}], 
        "]"}]}]}], "\[IndentingNewLine]", 
     RowBox[{"(*", 
      RowBox[{
       RowBox[{"**", "**", " ", "MANIPULATE"}], " ", "CONTROLS"}], " ", 
      "*****)"}], "\[IndentingNewLine]", ",", "\[IndentingNewLine]", 
     RowBox[{"Style", "[", 
      RowBox[{"\"\<Lines on the Cubic Surface\>\"", ",", "17", ",", "Bold"}], 
      "]"}], ",", "\[IndentingNewLine]", "Delimiter", ",", 
     "\[IndentingNewLine]", 
     RowBox[{"Style", "[", 
      RowBox[{
      "\"\<                     \[Kappa] = \!\(\*SuperscriptBox[\(x\), \(2\)]\
\) + \!\(\*SuperscriptBox[\(y\), \(2\)]\) + z\!\(\*SuperscriptBox[\(\\\ \), \
\(2\)]\)- xyz - 2\>\"", ",", "13"}], "]"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"k", ",", "18.0", ",", 
         RowBox[{"Style", "[", 
          RowBox[{"\"\<\[Kappa]\>\"", ",", "13"}], "]"}]}], "}"}], ",", 
       RowBox[{"-", "4.0"}], ",", "30.0", ",", "StepSize"}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "MyCubicOpacity", ",", "1", ",", " ", "\"\<Cubic Opacity\>\""}], 
        "}"}], ",", "0", ",", "1", ",", "0.1"}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"Zoom", ",", 
         RowBox[{"3", "/", "4"}], ",", "\"\<Zoom\>\""}], "}"}], ",", "1", ",", 
       RowBox[{"1", "/", "30"}], ",", "0.01"}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"viewX", ",", "0"}], "}"}], ",", 
       RowBox[{"-", "5"}], ",", "5"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"viewY", ",", 
         RowBox[{"-", "2"}]}], "}"}], ",", 
       RowBox[{"-", "5"}], ",", "5"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"viewZ", ",", "0"}], "}"}], ",", 
       RowBox[{"-", "5"}], ",", "5"}], "}"}], ",", " ", 
     RowBox[{"(*", 
      RowBox[{
       RowBox[{
        RowBox[{"changed", " ", "ViewY", " ", "from", " ", "2", " ", "to"}], 
        " ", "-", "2"}], ",", " ", 
       RowBox[{
        RowBox[{"4", "/", "15"}], "/", "2019"}]}], " ", "*)"}], 
     "\[IndentingNewLine]", 
     RowBox[{"Button", "[", 
      RowBox[{"\"\<Reset\>\"", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"k", "=", "18"}], ",", 
         RowBox[{"MyCubicOpacity", "=", "1"}], ",", 
         RowBox[{"Zoom", "=", 
          RowBox[{"1", "/", "2"}]}], ",", 
         RowBox[{"viewX", "=", "0"}], ",", 
         RowBox[{"viewZ", "=", "0"}], ",", 
         RowBox[{"viewY", "=", "2"}], ",", 
         RowBox[{"ShowIntersectionsQ", "=", "2"}], ",", 
         RowBox[{"ShowBoxQ", "=", "True"}], ",", 
         RowBox[{"RestrictPositiveQ", "=", "False"}], ",", 
         RowBox[{"LinesOn", "=", 
          RowBox[{"Range", "[", "24", "]"}]}], ",", 
         RowBox[{"lineColoring", "=", "xyzColoring"}]}], "}"}]}], "]"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "ShowIntersectionsQ", ",", "2", ",", "\"\<Intersections\>\""}], "}"}],
        ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"3", "\[Rule]", "\"\<Both\>\""}], ",", 
         RowBox[{"2", "\[Rule]", " ", "\"\<All\>\""}], ",", 
         RowBox[{"1", "\[Rule]", " ", "\"\<Eckhardt\>\""}], ",", 
         RowBox[{"0", "\[Rule]", "\"\<None\>\""}]}], "}"}]}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"ShowBoxQ", ",", "True", ",", "\"\<Show Box?\>\""}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"True", "\[Rule]", " ", "\"\<Yes\>\""}], ",", 
         RowBox[{"False", "\[Rule]", " ", "\"\<No\>\""}]}], "}"}]}], "}"}], 
     ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "RestrictPositiveQ", ",", "False", ",", "\"\<X, Y > 0 ?\>\""}], "}"}],
        ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"True", "\[Rule]", " ", "\"\<Yes\>\""}], ",", 
         RowBox[{"False", "\[Rule]", " ", "\"\<No\>\""}]}], "}"}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{"{", 
       RowBox[{"picName", ",", "\"\<cubic.bmp\>\"", ",", "\"\<Pic Name\>\""}],
        "}"}], "}"}], ",", 
     RowBox[{"Button", "[", 
      RowBox[{"\"\<Export Image\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"Export", "[", 
         RowBox[{"picName", ",", "exportMe", ",", 
          RowBox[{"ImageResolution", "\[Rule]", "200"}]}], "]"}], "}"}]}], 
      "]"}], ",", "\[IndentingNewLine]", 
     RowBox[{"Button", "[", 
      RowBox[{"\"\<Export View Data\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"Export", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"StringTake", "[", 
            RowBox[{"picName", ",", 
             RowBox[{"{", 
              RowBox[{"1", ",", 
               RowBox[{
                RowBox[{"StringLength", "[", "picName", "]"}], "-", "4"}]}], 
              "}"}]}], "]"}], "<>", "\"\< data.mx\>\""}], ",", 
          RowBox[{"{", 
           RowBox[{
           "k", ",", "MyCubicOpacity", ",", "Zoom", ",", "viewX", ",", 
            "viewY", ",", "viewZ", ",", "ShowIntersectionsQ", ",", "ShowBoxQ",
             ",", "RestrictPositiveQ", ",", "LinesOn", ",", "lineColoring"}], 
           "}"}]}], "]"}], "}"}]}], "]"}], ",", "\[IndentingNewLine]", 
     "Delimiter", ",", 
     RowBox[{"Column", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Text", "[", 
         RowBox[{"Style", "[", 
          RowBox[{"\"\<Load in Image Data\>\"", ",", 
           RowBox[{"{", "Bold", "}"}]}], "]"}], "]"}], ",", 
        RowBox[{"Row", "[", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"FileNameSetter", "[", 
            RowBox[{"Dynamic", "[", "fileToLoadDyn", "]"}], "]"}], ",", 
           RowBox[{"Dynamic", "[", 
            RowBox[{"NewLineFormatter", "[", "fileToLoadDyn", "]"}], "]"}]}], 
          "}"}], "]"}], ",", 
        RowBox[{"Button", "[", 
         RowBox[{"\"\<Load Data\>\"", ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
             "k", ",", "MyCubicOpacity", ",", "Zoom", ",", "viewX", ",", 
              "viewY", ",", "viewZ", ",", "ShowIntersectionsQ", ",", 
              "ShowBoxQ", ",", "RestrictPositiveQ", ",", "LinesOn", ",", 
              "lineColoring"}], "}"}], "=", 
            RowBox[{"Import", "[", "fileToLoadDyn", "]"}]}], "}"}]}], "]"}]}],
        "}"}], "]"}], ",", "\[IndentingNewLine]", "Delimiter", ",", 
     "\[IndentingNewLine]", 
     RowBox[{"Row", "[", 
      RowBox[{"{", 
       RowBox[{"TogglerBar", "[", 
        RowBox[{
         RowBox[{"Dynamic", "[", "LinesOn", "]"}], ",", " ", 
         "\[IndentingNewLine]", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{
            RowBox[{"{", "5", "}"}], "\[Rule]", " ", "\"\<\!\(\*
StyleBox[SubsuperscriptBox[\"CZ\", \"+\", \"+\"],
FontFamily->\"Times New Roman\",
FontSize->14,
FontWeight->\"Regular\"]\)\>\""}], ",", 
           RowBox[{
            RowBox[{"{", "6", "}"}], "\[Rule]", " ", "\"\<\!\(\*
StyleBox[SubsuperscriptBox[\"CZ\", \"-\", \"+\"],
FontFamily->\"Times New Roman\",
FontSize->14,
FontWeight->\"Plain\"]\)\>\""}], ",", 
           RowBox[{
            RowBox[{"{", "7", "}"}], "\[Rule]", " ", "\"\<\!\(\*
StyleBox[SubsuperscriptBox[\"CZ\", \"+\", \"-\"],
FontFamily->\"Times New Roman\",
FontSize->14,
FontWeight->\"Plain\"]\)\>\""}], ",", 
           RowBox[{
            RowBox[{"{", "8", "}"}], "\[Rule]", " ", "\"\<\!\(\*
StyleBox[SubsuperscriptBox[\"CZ\", \"-\", \"-\"],
FontFamily->\"Times New Roman\",
FontSize->14,
FontWeight->\"Plain\"]\)\>\""}], ",", "\[IndentingNewLine]", 
           RowBox[{
            RowBox[{"{", "13", "}"}], "\[Rule]", " ", "\"\<\!\(\*
StyleBox[SubsuperscriptBox[\"CY\", \"+\", \"+\"],
FontFamily->\"Times New Roman\",
FontSize->14,
FontWeight->\"Plain\"]\)\>\""}], ",", 
           RowBox[{
            RowBox[{"{", "14", "}"}], "\[Rule]", " ", "\"\<\!\(\*
StyleBox[SubsuperscriptBox[\"CY\", \"-\", \"+\"],
FontFamily->\"Times New Roman\",
FontSize->14,
FontWeight->\"Plain\"]\)\>\""}], ",", 
           RowBox[{
            RowBox[{"{", "15", "}"}], "\[Rule]", " ", "\"\<\!\(\*
StyleBox[SubsuperscriptBox[\"CY\", \"+\", \"-\"],
FontFamily->\"Times New Roman\",
FontSize->14,
FontWeight->\"Plain\"]\)\>\""}], ",", 
           RowBox[{
            RowBox[{"{", "16", "}"}], "\[Rule]", " ", "\"\<\!\(\*
StyleBox[SubsuperscriptBox[\"CY\", \"-\", \"-\"],
FontFamily->\"Times New Roman\",
FontSize->14,
FontWeight->\"Plain\"]\)\>\""}], ",", "\[IndentingNewLine]", 
           RowBox[{
            RowBox[{"{", "21", "}"}], "\[Rule]", " ", "\"\<\!\(\*
StyleBox[SubsuperscriptBox[\"CX\", \"+\", \"+\"],
FontFamily->\"Times New Roman\",
FontSize->14,
FontWeight->\"Plain\"]\)\>\""}], ",", 
           RowBox[{
            RowBox[{"{", "22", "}"}], "\[Rule]", " ", "\"\<\!\(\*
StyleBox[SubsuperscriptBox[\"CX\", \"-\", \"+\"],
FontFamily->\"Times New Roman\",
FontSize->14,
FontWeight->\"Plain\"]\)\>\""}], ",", 
           RowBox[{
            RowBox[{"{", "23", "}"}], "\[Rule]", " ", "\"\<\!\(\*
StyleBox[SubsuperscriptBox[\"CX\", \"+\", \"-\"],
FontFamily->\"Times New Roman\",
FontSize->14,
FontWeight->\"Plain\"]\)\>\""}], ",", 
           RowBox[{
            RowBox[{"{", "24", "}"}], "\[Rule]", " ", "\"\<\!\(\*
StyleBox[SubsuperscriptBox[\"CX\", \"-\", \"-\"],
FontFamily->\"Times New Roman\",
FontSize->14,
FontWeight->\"Plain\"]\)\>\""}], ",", "\[IndentingNewLine]", 
           RowBox[{
            RowBox[{"{", "1", "}"}], "\[Rule]", " ", "\"\<\!\(\*
StyleBox[SubsuperscriptBox[\"PZ\", \"+\", \"+\"],
FontFamily->\"Times New Roman\",
FontSize->14,
FontWeight->\"Plain\"]\)\>\""}], ",", 
           RowBox[{
            RowBox[{"{", "2", "}"}], "\[Rule]", " ", "\"\<\!\(\*
StyleBox[SubsuperscriptBox[\"PZ\", \"-\", \"+\"],
FontFamily->\"Times New Roman\",
FontSize->14,
FontWeight->\"Plain\"]\)\>\""}], ",", 
           RowBox[{
            RowBox[{"{", "3", "}"}], "\[Rule]", " ", "\"\<\!\(\*
StyleBox[SubsuperscriptBox[\"PZ\", \"+\", \"-\"],
FontFamily->\"Times New Roman\",
FontSize->14,
FontWeight->\"Plain\"]\)\>\""}], ",", 
           RowBox[{
            RowBox[{"{", "4", "}"}], "\[Rule]", " ", "\"\<\!\(\*
StyleBox[SubsuperscriptBox[\"PZ\", \"-\", \"-\"],
FontFamily->\"Times New Roman\",
FontSize->14,
FontWeight->\"Plain\"]\)\>\""}], ",", "\[IndentingNewLine]", 
           RowBox[{
            RowBox[{"{", "9", "}"}], "\[Rule]", " ", "\"\<\!\(\*
StyleBox[SubsuperscriptBox[\"PY\", \"+\", \"+\"],
FontFamily->\"Times New Roman\",
FontSize->14,
FontWeight->\"Plain\"]\)\>\""}], ",", 
           RowBox[{
            RowBox[{"{", "10", "}"}], "\[Rule]", " ", "\"\<\!\(\*
StyleBox[SubsuperscriptBox[\"PY\", \"-\", \"+\"],
FontFamily->\"Times New Roman\",
FontSize->14,
FontWeight->\"Plain\"]\)\>\""}], ",", 
           RowBox[{
            RowBox[{"{", "11", "}"}], "\[Rule]", " ", "\"\<\!\(\*
StyleBox[SubsuperscriptBox[\"PY\", \"+\", \"-\"],
FontFamily->\"Times New Roman\",
FontSize->14,
FontWeight->\"Plain\"]\)\>\""}], ",", 
           RowBox[{
            RowBox[{"{", "12", "}"}], "\[Rule]", " ", "\"\<\!\(\*
StyleBox[SubsuperscriptBox[\"PY\", \"-\", \"-\"],
FontFamily->\"Times New Roman\",
FontSize->14,
FontWeight->\"Plain\"]\)\>\""}], ",", "\[IndentingNewLine]", 
           RowBox[{
            RowBox[{"{", "17", "}"}], "\[Rule]", " ", "\"\<\!\(\*
StyleBox[SubsuperscriptBox[\"PX\", \"+\", \"+\"],
FontFamily->\"Times New Roman\",
FontSize->14,
FontWeight->\"Plain\"]\)\>\""}], ",", 
           RowBox[{
            RowBox[{"{", "18", "}"}], "\[Rule]", " ", "\"\<\!\(\*
StyleBox[SubsuperscriptBox[\"PX\", \"-\", \"+\"],
FontFamily->\"Times New Roman\",
FontSize->14,
FontWeight->\"Plain\"]\)\>\""}], ",", 
           RowBox[{
            RowBox[{"{", "19", "}"}], "\[Rule]", " ", "\"\<\!\(\*
StyleBox[SubsuperscriptBox[\"PX\", \"+\", \"-\"],
FontFamily->\"Times New Roman\",
FontSize->14,
FontWeight->\"Plain\"]\)\>\""}], ",", 
           RowBox[{
            RowBox[{"{", "20", "}"}], "\[Rule]", " ", "\"\<\!\(\*
StyleBox[SubsuperscriptBox[\"PX\", \"-\", \"-\"],
FontFamily->\"Times New Roman\",
FontSize->14,
FontWeight->\"Plain\"]\)\>\""}], ",", "\[IndentingNewLine]", 
           RowBox[{
            RowBox[{"Range", "[", "24", "]"}], "\[Rule]", " ", "\"\<\!\(\*
StyleBox[\"All\",
FontFamily->\"Times New Roman\",
FontSize->14,
FontWeight->\"Plain\"]\)\!\(\*
StyleBox[\" \",
FontFamily->\"Times New Roman\",
FontSize->14,
FontWeight->\"Plain\"]\)\!\(\*
StyleBox[\"Lines\",
FontFamily->\"Times New Roman\",
FontSize->14,
FontWeight->\"Plain\"]\)\>\""}], ",", "\[IndentingNewLine]", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
             "5", ",", "6", ",", "7", ",", "8", ",", "13", ",", "14", ",", 
              "15", ",", "16", ",", "21", ",", "22", ",", "23", ",", "24"}], 
             "}"}], "\[Rule]", "\"\<\!\(\*
StyleBox[\"C\",
FontFamily->\"Times New Roman\",
FontSize->14,
FontWeight->\"Plain\"]\)\!\(\*
StyleBox[\" \",
FontFamily->\"Times New Roman\",
FontSize->14,
FontWeight->\"Plain\"]\)\!\(\*
StyleBox[\"Lines\",
FontFamily->\"Times New Roman\",
FontSize->14,
FontWeight->\"Plain\"]\)\>\""}], ",", "\[IndentingNewLine]", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
             "1", ",", "2", ",", "3", ",", "4", ",", "9", ",", "10", ",", 
              "11", ",", "12", ",", "17", ",", "18", ",", "19", ",", "20"}], 
             "}"}], "\[Rule]", "\"\<\!\(\*
StyleBox[\"P\",
FontFamily->\"Times New Roman\",
FontSize->14,
FontWeight->\"Plain\"]\)\!\(\*
StyleBox[\" \",
FontFamily->\"Times New Roman\",
FontSize->14,
FontWeight->\"Plain\"]\)\!\(\*
StyleBox[\"Lines\",
FontFamily->\"Times New Roman\",
FontSize->14,
FontWeight->\"Plain\"]\)\>\""}]}], "}"}], ",", 
         RowBox[{"Appearance", "\[Rule]", 
          RowBox[{"\"\<Vertical\>\"", "\[Rule]", 
           RowBox[{"{", 
            RowBox[{"Automatic", ",", "8"}], "}"}]}]}]}], "]"}], "}"}], "]"}],
      ",", "Delimiter", ",", 
     RowBox[{"Style", "[", 
      RowBox[{"\"\<C Lines Schl\[ADoubleDot]fli Double Six\>\"", ",", "10"}], 
      "]"}], ",", 
     RowBox[{"Row", "[", 
      RowBox[{"{", 
       RowBox[{"TogglerBar", "[", 
        RowBox[{
         RowBox[{"Dynamic", "[", "LinesOn", "]"}], ",", " ", 
         "\[IndentingNewLine]", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{
            RowBox[{"{", 
             RowBox[{
             "5", ",", "13", ",", "21", ",", "7", ",", "15", ",", "23"}], 
             "}"}], "\[Rule]", " ", "\"\<First Sextuple\>\""}], ",", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
             "6", ",", "14", ",", "22", ",", "8", ",", "16", ",", "24"}], "}"}
             ], "\[Rule]", "\"\<Second Sextuple\>\""}]}], "  ", 
          "\[IndentingNewLine]", 
          RowBox[{"(*", 
           RowBox[{",", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{
              "1", ",", "2", ",", "3", ",", "4", ",", "9", ",", "10", ",", 
               "11", ",", "12", ",", "17", ",", "18", ",", "19", ",", "20"}], 
              "}"}], "\[Rule]", "\"\<P Lines (The Dozen)\>\""}]}], "*)"}], 
          "\[IndentingNewLine]", "}"}], ",", " ", 
         RowBox[{"Appearance", "\[Rule]", 
          RowBox[{"\"\<Vertical\>\"", "\[Rule]", 
           RowBox[{"{", 
            RowBox[{"Automatic", ",", "3"}], "}"}]}]}]}], "]"}], "}"}], "]"}],
      ",", "Delimiter", ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "lineColoring", ",", "xyzColoring", ",", 
         "\"\<Line Coloring Scheme\>\""}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"xyzColoring", "\[Rule]", "\"\<XYZ Coloring\>\""}], ",", 
         RowBox[{
         "CLinesSchlafiColoring", "\[Rule]", 
          "\"\<C Lines Schl\[ADoubleDot]fli Coloring\>\""}]}], "}"}]}], 
      "}"}]}], "\[IndentingNewLine]", "]"}], " ", 
   RowBox[{"(*", " ", 
    RowBox[{"End", " ", "of", " ", "Manipulate", " ", "block"}], " ", "*)"}], 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.742040697593021*^9, 3.742040732743729*^9}, {
   3.74204077855674*^9, 3.7420407816721897`*^9}, {3.7420779379949903`*^9, 
   3.7420779848012667`*^9}, {3.742078491872373*^9, 3.74207849862673*^9}, {
   3.742079627215876*^9, 3.742079627482382*^9}, 3.7420798377389*^9, {
   3.742081232694755*^9, 3.742081302343807*^9}, {3.742081348351017*^9, 
   3.74208155519631*^9}, {3.742081628002336*^9, 3.742081730776661*^9}, {
   3.7420850871338587`*^9, 3.74208508884263*^9}, {3.742085173548861*^9, 
   3.742085195879962*^9}, {3.742085254687984*^9, 3.742085255089768*^9}, {
   3.742085360464466*^9, 3.742085369292473*^9}, {3.7420891379978533`*^9, 
   3.7420891660808363`*^9}, {3.750036346236961*^9, 3.750036353218883*^9}, {
   3.7500364215942802`*^9, 3.7500364217246323`*^9}, {3.7500365408262243`*^9, 
   3.750036545856946*^9}, {3.750036712474619*^9, 3.7500367320187473`*^9}, 
   3.750036778959886*^9, {3.750090408609675*^9, 3.750090428595623*^9}, {
   3.75051413469765*^9, 3.750514260899191*^9}, {3.750514361509615*^9, 
   3.7505144424421463`*^9}, {3.7505145136855097`*^9, 3.750514565616108*^9}, {
   3.7505146090953093`*^9, 3.750514658023837*^9}, {3.7505147145288258`*^9, 
   3.750514962004033*^9}, {3.750515003829097*^9, 3.7505150049961357`*^9}, {
   3.750515074817341*^9, 3.750515076328438*^9}, {3.750515394171932*^9, 
   3.7505154306169558`*^9}, {3.750515613534235*^9, 3.7505157180568447`*^9}, {
   3.750515795388748*^9, 3.7505160044013653`*^9}, {3.750516136994961*^9, 
   3.750516137410285*^9}, {3.7505162704562397`*^9, 3.750516326335704*^9}, {
   3.7505163937234898`*^9, 3.7505163943819838`*^9}, {3.750516517598219*^9, 
   3.750516628954154*^9}, {3.750516771225821*^9, 3.750516799369656*^9}, {
   3.750516845268297*^9, 3.750516865518091*^9}, {3.750516967865944*^9, 
   3.75051698641917*^9}, {3.750517163316018*^9, 3.7505171965890303`*^9}, {
   3.7505172659841557`*^9, 3.7505172695793*^9}, {3.750517498022447*^9, 
   3.750517580878669*^9}, {3.7505176227996197`*^9, 3.75051766537173*^9}, {
   3.7505177129181767`*^9, 3.7505177570881863`*^9}, 3.750517918124091*^9, {
   3.750518322082551*^9, 3.7505183515102997`*^9}, 3.75051839251294*^9, {
   3.750518431436714*^9, 3.750518432083623*^9}, {3.750518469636047*^9, 
   3.7505184824419127`*^9}, {3.750518787916317*^9, 3.750518834520262*^9}, {
   3.7505189563059263`*^9, 3.750519035422139*^9}, {3.750519126670327*^9, 
   3.750519182655633*^9}, {3.751470095148953*^9, 3.751470098515066*^9}, {
   3.751470136341281*^9, 3.7514702074835663`*^9}, {3.751470238365677*^9, 
   3.7514704192586117`*^9}, {3.751470488448311*^9, 3.751470614925653*^9}, {
   3.75147077503118*^9, 3.751470887799602*^9}, {3.751470949565035*^9, 
   3.751470993577145*^9}, {3.7514710311668177`*^9, 3.751471303926424*^9}, {
   3.751471334709427*^9, 3.7514715475881977`*^9}, {3.751471587332172*^9, 
   3.751471599468357*^9}, {3.751471655042842*^9, 3.751471718169981*^9}, {
   3.751472194426915*^9, 3.751472248397462*^9}, {3.7514723374802933`*^9, 
   3.751472338718829*^9}, {3.7514724096973333`*^9, 3.751472443319069*^9}, {
   3.75147255747436*^9, 3.7514726094775352`*^9}, {3.752516809337418*^9, 
   3.752516872105991*^9}, {3.752516927322029*^9, 3.752516929692824*^9}, {
   3.75251710348426*^9, 3.752517108085047*^9}, {3.752517242793394*^9, 
   3.752517301349918*^9}, {3.7580421236721153`*^9, 3.758042151197146*^9}, {
   3.7580421896367903`*^9, 3.75804221321084*^9}, {3.7580422830120564`*^9, 
   3.75804230755317*^9}, {3.758557040057435*^9, 3.7585571018632107`*^9}, {
   3.758557187908337*^9, 3.758557242108244*^9}, {3.7585573487330017`*^9, 
   3.758557444400239*^9}, {3.7585575435770063`*^9, 3.75855757561277*^9}, {
   3.758557616078353*^9, 3.75855763492367*^9}, {3.758557780173615*^9, 
   3.7585578236202*^9}, {3.7585578926738043`*^9, 3.7585579103839808`*^9}, {
   3.758558050116888*^9, 3.758558164598576*^9}, {3.758558364755114*^9, 
   3.758558365691997*^9}, {3.7585585439637547`*^9, 3.7585585460844803`*^9}, {
   3.758558596851519*^9, 3.7585585991139517`*^9}, {3.758558642985758*^9, 
   3.758558689430632*^9}, {3.758558759392465*^9, 3.758558760405738*^9}, {
   3.758558881368882*^9, 3.758559036373996*^9}, {3.758559070203017*^9, 
   3.758559073753281*^9}, {3.758559105936372*^9, 3.758559107726243*^9}, {
   3.758559586475397*^9, 3.758559631032073*^9}, {3.75855978531686*^9, 
   3.758559814294118*^9}, {3.758559895744698*^9, 3.758559941357692*^9}, {
   3.7585599719837313`*^9, 3.758559990614064*^9}, {3.758560073819845*^9, 
   3.758560130778599*^9}, {3.758560180625351*^9, 3.758560266617958*^9}, {
   3.7585603160600443`*^9, 3.758560325057877*^9}, {3.758560358834969*^9, 
   3.758560389177143*^9}, {3.758560443206183*^9, 3.7585604468043747`*^9}, {
   3.758560477972746*^9, 3.758560478242689*^9}, {3.7585605149341917`*^9, 
   3.7585605166688023`*^9}, {3.758560549962914*^9, 3.7585606359719152`*^9}, {
   3.758560683166061*^9, 3.758560693275777*^9}, {3.758560831159525*^9, 
   3.758560840534424*^9}, {3.75856089344903*^9, 3.7585609191726923`*^9}, {
   3.7585609821717653`*^9, 3.758560986409546*^9}, {3.75856104700916*^9, 
   3.758561058338335*^9}, 3.75856109750483*^9, {3.7633743104673758`*^9, 
   3.763374314670497*^9}, {3.764324346867426*^9, 
   3.764324366446658*^9}},ExpressionUUID->"b6ff0f78-a0cb-4369-a0b9-\
bfe042eeab31"],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{$CellContext`k$$ = 18., $CellContext`lineColoring$$ = {
     RGBColor[1, 0, 0], 
     RGBColor[1, 0, 0], 
     RGBColor[1, 0, 0], 
     RGBColor[1, 0, 0], 
     RGBColor[1, 0, 0], 
     RGBColor[1, 0, 0], 
     RGBColor[1, 0, 0], 
     RGBColor[1, 0, 0], 
     RGBColor[0, 0, 1], 
     RGBColor[0, 0, 1], 
     RGBColor[0, 0, 1], 
     RGBColor[0, 0, 1], 
     RGBColor[0, 0, 1], 
     RGBColor[0, 0, 1], 
     RGBColor[0, 0, 1], 
     RGBColor[0, 0, 1], 
     RGBColor[0, 1, 0], 
     RGBColor[0, 1, 0], 
     RGBColor[0, 1, 0], 
     RGBColor[0, 1, 0], 
     RGBColor[0, 1, 0], 
     RGBColor[0, 1, 0], 
     RGBColor[0, 1, 0], 
     RGBColor[0, 1, 0]}, $CellContext`MyCubicOpacity$$ = 
    0.8, $CellContext`picName$$ = 
    "cubic.bmp", $CellContext`RestrictPositiveQ$$ = 
    False, $CellContext`ShowBoxQ$$ = True, $CellContext`ShowIntersectionsQ$$ =
     1, $CellContext`viewX$$ = 
    0, $CellContext`viewY$$ = -2, $CellContext`viewZ$$ = 
    0, $CellContext`Zoom$$ = Rational[3, 4], Typeset`show$$ = True, 
    Typeset`bookmarkList$$ = {}, Typeset`bookmarkMode$$ = "Menu", 
    Typeset`animator$$, Typeset`animvar$$ = 1, Typeset`name$$ = 
    "\"untitled\"", Typeset`specs$$ = {{
      Hold[
       Style["Lines on the Cubic Surface", 17, Bold]], 
      Manipulate`Dump`ThisIsNotAControl}, {
      Hold[
       Style[
       "                     \[Kappa] = \!\(\*SuperscriptBox[\(x\), \(2\)]\) \
+ \!\(\*SuperscriptBox[\(y\), \(2\)]\) + z\!\(\*SuperscriptBox[\(\\ \), \
\(2\)]\)- xyz - 2", 13]], Manipulate`Dump`ThisIsNotAControl}, {{
       Hold[$CellContext`k$$], 18., 
       Style["\[Kappa]", 13]}, -4., 30., 1}, {{
       Hold[$CellContext`MyCubicOpacity$$], 1, "Cubic Opacity"}, 0, 1, 0.1}, {{
       Hold[$CellContext`Zoom$$], 
       Rational[3, 4], "Zoom"}, 1, 
      Rational[1, 30], 0.01}, {{
       Hold[$CellContext`viewX$$], 0}, -5, 5}, {{
       Hold[$CellContext`viewY$$], 2}, -5, 5}, {{
       Hold[$CellContext`viewZ$$], 0}, -5, 5}, {
      Hold[
       Button[
       "Reset", {$CellContext`k$$ = 18, $CellContext`MyCubicOpacity$$ = 
         1, $CellContext`Zoom$$ = 1/2, $CellContext`viewX$$ = 
         0, $CellContext`viewZ$$ = 0, $CellContext`viewY$$ = 
         2, $CellContext`ShowIntersectionsQ$$ = 2, $CellContext`ShowBoxQ$$ = 
         True, $CellContext`RestrictPositiveQ$$ = False, $CellContext`LinesOn = 
         Range[24], $CellContext`lineColoring$$ = $CellContext`xyzColoring}]],
       Manipulate`Dump`ThisIsNotAControl}, {{
       Hold[$CellContext`ShowIntersectionsQ$$], 2, "Intersections"}, {
      3 -> "Both", 2 -> "All", 1 -> "Eckhardt", 0 -> "None"}}, {{
       Hold[$CellContext`ShowBoxQ$$], True, "Show Box?"}, {
      True -> "Yes", False -> "No"}}, {{
       Hold[$CellContext`RestrictPositiveQ$$], False, "X, Y > 0 ?"}, {
      True -> "Yes", False -> "No"}}, {{
       Hold[$CellContext`picName$$], "cubic.bmp", "Pic Name"}}, {
      Hold[
       Button["Export Image", {
         Export[$CellContext`picName$$, $CellContext`exportMe, 
          ImageResolution -> 200]}]], Manipulate`Dump`ThisIsNotAControl}, {
      Hold[
       Button["Export View Data", {
         Export[
          StringJoin[
           
           StringTake[$CellContext`picName$$, {
            1, StringLength[$CellContext`picName$$] - 4}], 
           " data.mx"], {$CellContext`k$$, $CellContext`MyCubicOpacity$$, \
$CellContext`Zoom$$, $CellContext`viewX$$, $CellContext`viewY$$, \
$CellContext`viewZ$$, $CellContext`ShowIntersectionsQ$$, \
$CellContext`ShowBoxQ$$, $CellContext`RestrictPositiveQ$$, \
$CellContext`LinesOn, $CellContext`lineColoring$$}]}]], 
      Manipulate`Dump`ThisIsNotAControl}, {
      Hold[
       Column[{
         Text[
          Style["Load in Image Data", {Bold}]], 
         Row[{
           FileNameSetter[
            Dynamic[$CellContext`fileToLoadDyn]], 
           Dynamic[
            $CellContext`NewLineFormatter[$CellContext`fileToLoadDyn]]}], 
         Button[
         "Load Data", {{$CellContext`k$$, $CellContext`MyCubicOpacity$$, \
$CellContext`Zoom$$, $CellContext`viewX$$, $CellContext`viewY$$, \
$CellContext`viewZ$$, $CellContext`ShowIntersectionsQ$$, \
$CellContext`ShowBoxQ$$, $CellContext`RestrictPositiveQ$$, \
$CellContext`LinesOn, $CellContext`lineColoring$$} = 
           Import[$CellContext`fileToLoadDyn]}]}]], 
      Manipulate`Dump`ThisIsNotAControl}, {
      Hold[
       Row[{
         TogglerBar[
          
          Dynamic[$CellContext`LinesOn], {{5} -> 
           "\!\(\*\nStyleBox[SubsuperscriptBox[\"CZ\", \"+\", \"+\"],\n\
FontFamily->\"Times New Roman\",\nFontSize->14,\nFontWeight->\"Regular\"]\)", \
{6} -> "\!\(\*\nStyleBox[SubsuperscriptBox[\"CZ\", \"-\", \"+\"],\n\
FontFamily->\"Times New Roman\",\nFontSize->14,\nFontWeight->\"Plain\"]\)", {
            7} -> "\!\(\*\nStyleBox[SubsuperscriptBox[\"CZ\", \"+\", \"-\"],\n\
FontFamily->\"Times New Roman\",\nFontSize->14,\nFontWeight->\"Plain\"]\)", {
            8} -> "\!\(\*\nStyleBox[SubsuperscriptBox[\"CZ\", \"-\", \"-\"],\n\
FontFamily->\"Times New Roman\",\nFontSize->14,\nFontWeight->\"Plain\"]\)", {
            13} -> "\!\(\*\nStyleBox[SubsuperscriptBox[\"CY\", \"+\", \"+\"],\
\nFontFamily->\"Times New Roman\",\nFontSize->14,\nFontWeight->\"Plain\"]\)", \
{14} -> "\!\(\*\nStyleBox[SubsuperscriptBox[\"CY\", \"-\", \"+\"],\n\
FontFamily->\"Times New Roman\",\nFontSize->14,\nFontWeight->\"Plain\"]\)", {
            15} -> "\!\(\*\nStyleBox[SubsuperscriptBox[\"CY\", \"+\", \"-\"],\
\nFontFamily->\"Times New Roman\",\nFontSize->14,\nFontWeight->\"Plain\"]\)", \
{16} -> "\!\(\*\nStyleBox[SubsuperscriptBox[\"CY\", \"-\", \"-\"],\n\
FontFamily->\"Times New Roman\",\nFontSize->14,\nFontWeight->\"Plain\"]\)", {
            21} -> "\!\(\*\nStyleBox[SubsuperscriptBox[\"CX\", \"+\", \"+\"],\
\nFontFamily->\"Times New Roman\",\nFontSize->14,\nFontWeight->\"Plain\"]\)", \
{22} -> "\!\(\*\nStyleBox[SubsuperscriptBox[\"CX\", \"-\", \"+\"],\n\
FontFamily->\"Times New Roman\",\nFontSize->14,\nFontWeight->\"Plain\"]\)", {
            23} -> 
           "\!\(\*\nStyleBox[SubsuperscriptBox[\"CX\", \"+\", \"-\"],\n\
FontFamily->\"Times New Roman\",\nFontSize->14,\nFontWeight->\"Plain\"]\)", {
            24} -> "\!\(\*\nStyleBox[SubsuperscriptBox[\"CX\", \"-\", \"-\"],\
\nFontFamily->\"Times New Roman\",\nFontSize->14,\nFontWeight->\"Plain\"]\)", \
{1} -> "\!\(\*\nStyleBox[SubsuperscriptBox[\"PZ\", \"+\", \"+\"],\n\
FontFamily->\"Times New Roman\",\nFontSize->14,\nFontWeight->\"Plain\"]\)", {
            2} -> "\!\(\*\nStyleBox[SubsuperscriptBox[\"PZ\", \"-\", \"+\"],\n\
FontFamily->\"Times New Roman\",\nFontSize->14,\nFontWeight->\"Plain\"]\)", {
            3} -> "\!\(\*\nStyleBox[SubsuperscriptBox[\"PZ\", \"+\", \"-\"],\n\
FontFamily->\"Times New Roman\",\nFontSize->14,\nFontWeight->\"Plain\"]\)", {
            4} -> "\!\(\*\nStyleBox[SubsuperscriptBox[\"PZ\", \"-\", \"-\"],\n\
FontFamily->\"Times New Roman\",\nFontSize->14,\nFontWeight->\"Plain\"]\)", {
            9} -> "\!\(\*\nStyleBox[SubsuperscriptBox[\"PY\", \"+\", \"+\"],\n\
FontFamily->\"Times New Roman\",\nFontSize->14,\nFontWeight->\"Plain\"]\)", {
            10} -> "\!\(\*\nStyleBox[SubsuperscriptBox[\"PY\", \"-\", \"+\"],\
\nFontFamily->\"Times New Roman\",\nFontSize->14,\nFontWeight->\"Plain\"]\)", \
{11} -> "\!\(\*\nStyleBox[SubsuperscriptBox[\"PY\", \"+\", \"-\"],\n\
FontFamily->\"Times New Roman\",\nFontSize->14,\nFontWeight->\"Plain\"]\)", {
            12} -> "\!\(\*\nStyleBox[SubsuperscriptBox[\"PY\", \"-\", \"-\"],\
\nFontFamily->\"Times New Roman\",\nFontSize->14,\nFontWeight->\"Plain\"]\)", \
{17} -> "\!\(\*\nStyleBox[SubsuperscriptBox[\"PX\", \"+\", \"+\"],\n\
FontFamily->\"Times New Roman\",\nFontSize->14,\nFontWeight->\"Plain\"]\)", {
            18} -> "\!\(\*\nStyleBox[SubsuperscriptBox[\"PX\", \"-\", \"+\"],\
\nFontFamily->\"Times New Roman\",\nFontSize->14,\nFontWeight->\"Plain\"]\)", \
{19} -> "\!\(\*\nStyleBox[SubsuperscriptBox[\"PX\", \"+\", \"-\"],\n\
FontFamily->\"Times New Roman\",\nFontSize->14,\nFontWeight->\"Plain\"]\)", {
            20} -> 
           "\!\(\*\nStyleBox[SubsuperscriptBox[\"PX\", \"-\", \"-\"],\n\
FontFamily->\"Times New Roman\",\nFontSize->14,\nFontWeight->\"Plain\"]\)", {
            1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19,
             20, 21, 22, 23, 24} -> 
           "\!\(\*\nStyleBox[\"All\",\nFontFamily->\"Times New Roman\",\n\
FontSize->14,\nFontWeight->\"Plain\"]\)\!\(\*\nStyleBox[\" \",\n\
FontFamily->\"Times New Roman\",\nFontSize->14,\nFontWeight->\"Plain\"]\)\!\(\
\*\nStyleBox[\"Lines\",\nFontFamily->\"Times New Roman\",\nFontSize->14,\n\
FontWeight->\"Plain\"]\)", {5, 6, 7, 8, 13, 14, 15, 16, 21, 22, 23, 24} -> 
           "\!\(\*\nStyleBox[\"C\",\nFontFamily->\"Times New Roman\",\n\
FontSize->14,\nFontWeight->\"Plain\"]\)\!\(\*\nStyleBox[\" \",\n\
FontFamily->\"Times New Roman\",\nFontSize->14,\nFontWeight->\"Plain\"]\)\!\(\
\*\nStyleBox[\"Lines\",\nFontFamily->\"Times New Roman\",\nFontSize->14,\n\
FontWeight->\"Plain\"]\)", {1, 2, 3, 4, 9, 10, 11, 12, 17, 18, 19, 20} -> 
           "\!\(\*\nStyleBox[\"P\",\nFontFamily->\"Times New Roman\",\n\
FontSize->14,\nFontWeight->\"Plain\"]\)\!\(\*\nStyleBox[\" \",\n\
FontFamily->\"Times New Roman\",\nFontSize->14,\nFontWeight->\"Plain\"]\)\!\(\
\*\nStyleBox[\"Lines\",\nFontFamily->\"Times New Roman\",\nFontSize->14,\n\
FontWeight->\"Plain\"]\)"}, Appearance -> ("Vertical" -> {Automatic, 8})]}]], 
      Manipulate`Dump`ThisIsNotAControl}, {
      Hold[
       Style["C Lines Schl\[ADoubleDot]fli Double Six", 10]], 
      Manipulate`Dump`ThisIsNotAControl}, {
      Hold[
       Row[{
         TogglerBar[
          
          Dynamic[$CellContext`LinesOn], {{5, 13, 21, 7, 15, 23} -> 
           "First Sextuple", {6, 14, 22, 8, 16, 24} -> "Second Sextuple"}, 
          Appearance -> ("Vertical" -> {Automatic, 3})]}]], 
      Manipulate`Dump`ThisIsNotAControl}, {{
       Hold[$CellContext`lineColoring$$], {
        RGBColor[1, 0, 0], 
        RGBColor[1, 0, 0], 
        RGBColor[1, 0, 0], 
        RGBColor[1, 0, 0], 
        RGBColor[1, 0, 0], 
        RGBColor[1, 0, 0], 
        RGBColor[1, 0, 0], 
        RGBColor[1, 0, 0], 
        RGBColor[0, 0, 1], 
        RGBColor[0, 0, 1], 
        RGBColor[0, 0, 1], 
        RGBColor[0, 0, 1], 
        RGBColor[0, 0, 1], 
        RGBColor[0, 0, 1], 
        RGBColor[0, 0, 1], 
        RGBColor[0, 0, 1], 
        RGBColor[0, 1, 0], 
        RGBColor[0, 1, 0], 
        RGBColor[0, 1, 0], 
        RGBColor[0, 1, 0], 
        RGBColor[0, 1, 0], 
        RGBColor[0, 1, 0], 
        RGBColor[0, 1, 0], 
        RGBColor[0, 1, 0]}, "Line Coloring Scheme"}, {{
         RGBColor[1, 0, 0], 
         RGBColor[1, 0, 0], 
         RGBColor[1, 0, 0], 
         RGBColor[1, 0, 0], 
         RGBColor[1, 0, 0], 
         RGBColor[1, 0, 0], 
         RGBColor[1, 0, 0], 
         RGBColor[1, 0, 0], 
         RGBColor[0, 0, 1], 
         RGBColor[0, 0, 1], 
         RGBColor[0, 0, 1], 
         RGBColor[0, 0, 1], 
         RGBColor[0, 0, 1], 
         RGBColor[0, 0, 1], 
         RGBColor[0, 0, 1], 
         RGBColor[0, 0, 1], 
         RGBColor[0, 1, 0], 
         RGBColor[0, 1, 0], 
         RGBColor[0, 1, 0], 
         RGBColor[0, 1, 0], 
         RGBColor[0, 1, 0], 
         RGBColor[0, 1, 0], 
         RGBColor[0, 1, 0], 
         RGBColor[0, 1, 0]} -> "XYZ Coloring", {
         RGBColor[1, 1, 0], 
         RGBColor[1, 1, 0], 
         RGBColor[1, 1, 0], 
         RGBColor[1, 1, 0], 
         RGBColor[1, 0, 1], 
         RGBColor[0, 1, 1], 
         RGBColor[1, 0, 1], 
         RGBColor[0, 1, 1], 
         RGBColor[1, 1, 0], 
         RGBColor[1, 1, 0], 
         RGBColor[1, 1, 0], 
         RGBColor[1, 1, 0], 
         RGBColor[1, 0, 1], 
         RGBColor[0, 1, 1], 
         RGBColor[1, 0, 1], 
         RGBColor[0, 1, 1], 
         RGBColor[1, 1, 0], 
         RGBColor[1, 1, 0], 
         RGBColor[1, 1, 0], 
         RGBColor[1, 1, 0], 
         RGBColor[1, 0, 1], 
         RGBColor[0, 1, 1], 
         RGBColor[1, 0, 1], 
         RGBColor[0, 1, 1]} -> "C Lines Schl\[ADoubleDot]fli Coloring"}}}, 
    Typeset`size$$ = {750., {376., 383.}}, Typeset`update$$ = 0, 
    Typeset`initDone$$, Typeset`skipInitDone$$ = True, $CellContext`k$5205$$ =
     0, $CellContext`MyCubicOpacity$5210$$ = 0, $CellContext`Zoom$5211$$ = 
    0, $CellContext`viewX$5212$$ = 0, $CellContext`viewY$5213$$ = 
    0, $CellContext`viewZ$5214$$ = 0, $CellContext`ShowIntersectionsQ$5215$$ =
     False, $CellContext`ShowBoxQ$5216$$ = 
    False, $CellContext`RestrictPositiveQ$5217$$ = 
    False, $CellContext`lineColoring$5218$$ = False}, 
    DynamicBox[Manipulate`ManipulateBoxes[
     1, StandardForm, 
      "Variables" :> {$CellContext`k$$ = 18., $CellContext`lineColoring$$ = {
          RGBColor[1, 0, 0], 
          RGBColor[1, 0, 0], 
          RGBColor[1, 0, 0], 
          RGBColor[1, 0, 0], 
          RGBColor[1, 0, 0], 
          RGBColor[1, 0, 0], 
          RGBColor[1, 0, 0], 
          RGBColor[1, 0, 0], 
          RGBColor[0, 0, 1], 
          RGBColor[0, 0, 1], 
          RGBColor[0, 0, 1], 
          RGBColor[0, 0, 1], 
          RGBColor[0, 0, 1], 
          RGBColor[0, 0, 1], 
          RGBColor[0, 0, 1], 
          RGBColor[0, 0, 1], 
          RGBColor[0, 1, 0], 
          RGBColor[0, 1, 0], 
          RGBColor[0, 1, 0], 
          RGBColor[0, 1, 0], 
          RGBColor[0, 1, 0], 
          RGBColor[0, 1, 0], 
          RGBColor[0, 1, 0], 
          RGBColor[0, 1, 0]}, $CellContext`MyCubicOpacity$$ = 
        1, $CellContext`picName$$ = 
        "cubic.bmp", $CellContext`RestrictPositiveQ$$ = 
        False, $CellContext`ShowBoxQ$$ = 
        True, $CellContext`ShowIntersectionsQ$$ = 2, $CellContext`viewX$$ = 
        0, $CellContext`viewY$$ = 2, $CellContext`viewZ$$ = 
        0, $CellContext`Zoom$$ = Rational[3, 4]}, "ControllerVariables" :> {
        Hold[$CellContext`k$$, $CellContext`k$5205$$, 0], 
        Hold[$CellContext`MyCubicOpacity$$, \
$CellContext`MyCubicOpacity$5210$$, 0], 
        Hold[$CellContext`Zoom$$, $CellContext`Zoom$5211$$, 0], 
        Hold[$CellContext`viewX$$, $CellContext`viewX$5212$$, 0], 
        Hold[$CellContext`viewY$$, $CellContext`viewY$5213$$, 0], 
        Hold[$CellContext`viewZ$$, $CellContext`viewZ$5214$$, 0], 
        Hold[$CellContext`ShowIntersectionsQ$$, \
$CellContext`ShowIntersectionsQ$5215$$, False], 
        Hold[$CellContext`ShowBoxQ$$, $CellContext`ShowBoxQ$5216$$, False], 
        Hold[$CellContext`RestrictPositiveQ$$, \
$CellContext`RestrictPositiveQ$5217$$, False], 
        Hold[$CellContext`lineColoring$$, $CellContext`lineColoring$5218$$, 
         False]}, 
      "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, 
      "Body" :> ($CellContext`iter = 
        Round[($CellContext`k$$ - \
$CellContext`KappaMin)/$CellContext`StepSize] + 1; $CellContext`MyStuffToShow = {
          Opacity[$CellContext`MyCubicOpacity$$], 
          Part[$CellContext`MyCubic, $CellContext`iter]}; 
       If[$CellContext`k$$ >= 
         2, $CellContext`LinesOnFiltered = DeleteDuplicates[
            Flatten[$CellContext`LinesOn]]; $CellContext`TubeWidth = 
          0.17 $CellContext`Zoom$$; $CellContext`GraphicsAll24LinesUncolored = 
          Map[{
             Tube[#, $CellContext`TubeWidth]}& , 
            Part[
             Part[$CellContext`TwoPointsAll24Lines, $CellContext`iter], 
             Range[24]]]; $CellContext`GraphicsAll24Lines = Partition[
            
            Riffle[$CellContext`lineColoring$$, \
$CellContext`GraphicsAll24LinesUncolored], 2]; 
         Switch[$CellContext`ShowIntersectionsQ$$, 
           3, $CellContext`MyStuffToShow = {{
               Opacity[$CellContext`MyCubicOpacity$$], 
               Part[$CellContext`MyCubic, $CellContext`iter]}, 
              
              Part[$CellContext`GraphicsAll24Lines, \
$CellContext`LinesOnFiltered], {{White, 
                Sphere[
                 DeleteCases[
                  Flatten[
                   Part[
                    
                    Part[$CellContext`Intersections, $CellContext`iter], \
$CellContext`LinesOnFiltered, $CellContext`LinesOnFiltered], 1], {}], 
                 0.6 $CellContext`Zoom$$]}}, 
              If[$CellContext`k$$ == 18, 
               $CellContext`EckhardtPoints[$CellContext`Zoom$$], {}]}; Null, 
           2, $CellContext`MyStuffToShow = {{
              Opacity[$CellContext`MyCubicOpacity$$], 
              Part[$CellContext`MyCubic, $CellContext`iter]}, 
             
             Part[$CellContext`GraphicsAll24Lines, \
$CellContext`LinesOnFiltered], {{White, 
               Sphere[
                DeleteCases[
                 Flatten[
                  Part[
                   
                   Part[$CellContext`Intersections, $CellContext`iter], \
$CellContext`LinesOnFiltered, $CellContext`LinesOnFiltered], 1], {}], 
                0.6 $CellContext`Zoom$$]}}}, 1, $CellContext`MyStuffToShow = {{
               Opacity[$CellContext`MyCubicOpacity$$], 
               Part[$CellContext`MyCubic, $CellContext`iter]}, 
              
              Part[$CellContext`GraphicsAll24Lines, \
$CellContext`LinesOnFiltered], 
              If[$CellContext`k$$ == 18, 
               $CellContext`EckhardtPoints[$CellContext`Zoom$$], {}]}; Null, 
           0, $CellContext`MyStuffToShow = {{
               Opacity[$CellContext`MyCubicOpacity$$], 
               Part[$CellContext`MyCubic, $CellContext`iter]}, 
              
              Part[$CellContext`GraphicsAll24Lines, \
$CellContext`LinesOnFiltered]}; Null]; Null]; $CellContext`ZMin = 
        If[$CellContext`k$$ < -2, 0, 
          Sqrt[$CellContext`k$$ + 2]]; $CellContext`exportMe = 
        Graphics3D[{$CellContext`MyStuffToShow}, PlotRange -> 
          If[$CellContext`RestrictPositiveQ$$, {{
             0, $CellContext`CubicPlotRange $CellContext`Zoom$$}, {
             0, $CellContext`CubicPlotRange $CellContext`Zoom$$}, \
{-$CellContext`ZMin, $CellContext`CubicPlotRange $CellContext`Zoom$$}}, \
$CellContext`CubicPlotRange $CellContext`Zoom$$], ImageSize -> 500, 
          Boxed -> $CellContext`ShowBoxQ$$, Axes -> $CellContext`ShowBoxQ$$, 
          AxesLabel -> {"x", "y", "z"}, 
          ViewPoint -> {$CellContext`viewX$$, $CellContext`viewY$$, \
$CellContext`viewZ$$}]), "Specifications" :> {
        Style["Lines on the Cubic Surface", 17, Bold], Delimiter, 
        Style[
        "                     \[Kappa] = \!\(\*SuperscriptBox[\(x\), \(2\)]\) \
+ \!\(\*SuperscriptBox[\(y\), \(2\)]\) + z\!\(\*SuperscriptBox[\(\\ \), \
\(2\)]\)- xyz - 2", 13], {{$CellContext`k$$, 18., 
          Style["\[Kappa]", 13]}, -4., 30., 
         1}, {{$CellContext`MyCubicOpacity$$, 1, "Cubic Opacity"}, 0, 1, 
         0.1}, {{$CellContext`Zoom$$, 
          Rational[3, 4], "Zoom"}, 1, 
         Rational[1, 30], 0.01}, {{$CellContext`viewX$$, 0}, -5, 
         5}, {{$CellContext`viewY$$, 2}, -5, 
         5}, {{$CellContext`viewZ$$, 0}, -5, 5}, 
        Button[
        "Reset", {$CellContext`k$$ = 18, $CellContext`MyCubicOpacity$$ = 
          1, $CellContext`Zoom$$ = 1/2, $CellContext`viewX$$ = 
          0, $CellContext`viewZ$$ = 0, $CellContext`viewY$$ = 
          2, $CellContext`ShowIntersectionsQ$$ = 2, $CellContext`ShowBoxQ$$ = 
          True, $CellContext`RestrictPositiveQ$$ = 
          False, $CellContext`LinesOn = 
          Range[24], $CellContext`lineColoring$$ = \
$CellContext`xyzColoring}], {{$CellContext`ShowIntersectionsQ$$, 2, 
          "Intersections"}, {
         3 -> "Both", 2 -> "All", 1 -> "Eckhardt", 0 -> 
          "None"}}, {{$CellContext`ShowBoxQ$$, True, "Show Box?"}, {
         True -> "Yes", False -> "No"}}, {{$CellContext`RestrictPositiveQ$$, 
          False, "X, Y > 0 ?"}, {
         True -> "Yes", False -> "No"}}, {{$CellContext`picName$$, 
          "cubic.bmp", "Pic Name"}}, 
        Button["Export Image", {
          Export[$CellContext`picName$$, $CellContext`exportMe, 
           ImageResolution -> 200]}], 
        Button["Export View Data", {
          Export[
           StringJoin[
            
            StringTake[$CellContext`picName$$, {
             1, StringLength[$CellContext`picName$$] - 4}], 
            " data.mx"], {$CellContext`k$$, $CellContext`MyCubicOpacity$$, \
$CellContext`Zoom$$, $CellContext`viewX$$, $CellContext`viewY$$, \
$CellContext`viewZ$$, $CellContext`ShowIntersectionsQ$$, \
$CellContext`ShowBoxQ$$, $CellContext`RestrictPositiveQ$$, \
$CellContext`LinesOn, $CellContext`lineColoring$$}]}], Delimiter, 
        Column[{
          Text[
           Style["Load in Image Data", {Bold}]], 
          Row[{
            FileNameSetter[
             Dynamic[$CellContext`fileToLoadDyn]], 
            Dynamic[
             $CellContext`NewLineFormatter[$CellContext`fileToLoadDyn]]}], 
          Button[
          "Load Data", {{$CellContext`k$$, $CellContext`MyCubicOpacity$$, \
$CellContext`Zoom$$, $CellContext`viewX$$, $CellContext`viewY$$, \
$CellContext`viewZ$$, $CellContext`ShowIntersectionsQ$$, \
$CellContext`ShowBoxQ$$, $CellContext`RestrictPositiveQ$$, \
$CellContext`LinesOn, $CellContext`lineColoring$$} = 
            Import[$CellContext`fileToLoadDyn]}]}], Delimiter, 
        Row[{
          TogglerBar[
           
           Dynamic[$CellContext`LinesOn], {{5} -> 
            "\!\(\*\nStyleBox[SubsuperscriptBox[\"CZ\", \"+\", \"+\"],\n\
FontFamily->\"Times New Roman\",\nFontSize->14,\nFontWeight->\"Regular\"]\)", \
{6} -> "\!\(\*\nStyleBox[SubsuperscriptBox[\"CZ\", \"-\", \"+\"],\n\
FontFamily->\"Times New Roman\",\nFontSize->14,\nFontWeight->\"Plain\"]\)", {
             7} -> "\!\(\*\nStyleBox[SubsuperscriptBox[\"CZ\", \"+\", \"-\"],\
\nFontFamily->\"Times New Roman\",\nFontSize->14,\nFontWeight->\"Plain\"]\)", \
{8} -> "\!\(\*\nStyleBox[SubsuperscriptBox[\"CZ\", \"-\", \"-\"],\n\
FontFamily->\"Times New Roman\",\nFontSize->14,\nFontWeight->\"Plain\"]\)", {
             13} -> 
            "\!\(\*\nStyleBox[SubsuperscriptBox[\"CY\", \"+\", \"+\"],\n\
FontFamily->\"Times New Roman\",\nFontSize->14,\nFontWeight->\"Plain\"]\)", {
             14} -> "\!\(\*\nStyleBox[SubsuperscriptBox[\"CY\", \"-\", \
\"+\"],\nFontFamily->\"Times New Roman\",\nFontSize->14,\nFontWeight->\"Plain\
\"]\)", {15} -> 
            "\!\(\*\nStyleBox[SubsuperscriptBox[\"CY\", \"+\", \"-\"],\n\
FontFamily->\"Times New Roman\",\nFontSize->14,\nFontWeight->\"Plain\"]\)", {
             16} -> "\!\(\*\nStyleBox[SubsuperscriptBox[\"CY\", \"-\", \
\"-\"],\nFontFamily->\"Times New Roman\",\nFontSize->14,\nFontWeight->\"Plain\
\"]\)", {21} -> 
            "\!\(\*\nStyleBox[SubsuperscriptBox[\"CX\", \"+\", \"+\"],\n\
FontFamily->\"Times New Roman\",\nFontSize->14,\nFontWeight->\"Plain\"]\)", {
             22} -> "\!\(\*\nStyleBox[SubsuperscriptBox[\"CX\", \"-\", \
\"+\"],\nFontFamily->\"Times New Roman\",\nFontSize->14,\nFontWeight->\"Plain\
\"]\)", {23} -> 
            "\!\(\*\nStyleBox[SubsuperscriptBox[\"CX\", \"+\", \"-\"],\n\
FontFamily->\"Times New Roman\",\nFontSize->14,\nFontWeight->\"Plain\"]\)", {
             24} -> "\!\(\*\nStyleBox[SubsuperscriptBox[\"CX\", \"-\", \
\"-\"],\nFontFamily->\"Times New Roman\",\nFontSize->14,\nFontWeight->\"Plain\
\"]\)", {1} -> 
            "\!\(\*\nStyleBox[SubsuperscriptBox[\"PZ\", \"+\", \"+\"],\n\
FontFamily->\"Times New Roman\",\nFontSize->14,\nFontWeight->\"Plain\"]\)", {
             2} -> "\!\(\*\nStyleBox[SubsuperscriptBox[\"PZ\", \"-\", \"+\"],\
\nFontFamily->\"Times New Roman\",\nFontSize->14,\nFontWeight->\"Plain\"]\)", \
{3} -> "\!\(\*\nStyleBox[SubsuperscriptBox[\"PZ\", \"+\", \"-\"],\n\
FontFamily->\"Times New Roman\",\nFontSize->14,\nFontWeight->\"Plain\"]\)", {
             4} -> "\!\(\*\nStyleBox[SubsuperscriptBox[\"PZ\", \"-\", \"-\"],\
\nFontFamily->\"Times New Roman\",\nFontSize->14,\nFontWeight->\"Plain\"]\)", \
{9} -> "\!\(\*\nStyleBox[SubsuperscriptBox[\"PY\", \"+\", \"+\"],\n\
FontFamily->\"Times New Roman\",\nFontSize->14,\nFontWeight->\"Plain\"]\)", {
             10} -> 
            "\!\(\*\nStyleBox[SubsuperscriptBox[\"PY\", \"-\", \"+\"],\n\
FontFamily->\"Times New Roman\",\nFontSize->14,\nFontWeight->\"Plain\"]\)", {
             11} -> "\!\(\*\nStyleBox[SubsuperscriptBox[\"PY\", \"+\", \
\"-\"],\nFontFamily->\"Times New Roman\",\nFontSize->14,\nFontWeight->\"Plain\
\"]\)", {12} -> 
            "\!\(\*\nStyleBox[SubsuperscriptBox[\"PY\", \"-\", \"-\"],\n\
FontFamily->\"Times New Roman\",\nFontSize->14,\nFontWeight->\"Plain\"]\)", {
             17} -> "\!\(\*\nStyleBox[SubsuperscriptBox[\"PX\", \"+\", \
\"+\"],\nFontFamily->\"Times New Roman\",\nFontSize->14,\nFontWeight->\"Plain\
\"]\)", {18} -> 
            "\!\(\*\nStyleBox[SubsuperscriptBox[\"PX\", \"-\", \"+\"],\n\
FontFamily->\"Times New Roman\",\nFontSize->14,\nFontWeight->\"Plain\"]\)", {
             19} -> "\!\(\*\nStyleBox[SubsuperscriptBox[\"PX\", \"+\", \
\"-\"],\nFontFamily->\"Times New Roman\",\nFontSize->14,\nFontWeight->\"Plain\
\"]\)", {20} -> 
            "\!\(\*\nStyleBox[SubsuperscriptBox[\"PX\", \"-\", \"-\"],\n\
FontFamily->\"Times New Roman\",\nFontSize->14,\nFontWeight->\"Plain\"]\)", {
             1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 
             19, 20, 21, 22, 23, 24} -> 
            "\!\(\*\nStyleBox[\"All\",\nFontFamily->\"Times New Roman\",\n\
FontSize->14,\nFontWeight->\"Plain\"]\)\!\(\*\nStyleBox[\" \",\n\
FontFamily->\"Times New Roman\",\nFontSize->14,\nFontWeight->\"Plain\"]\)\!\(\
\*\nStyleBox[\"Lines\",\nFontFamily->\"Times New Roman\",\nFontSize->14,\n\
FontWeight->\"Plain\"]\)", {5, 6, 7, 8, 13, 14, 15, 16, 21, 22, 23, 24} -> 
            "\!\(\*\nStyleBox[\"C\",\nFontFamily->\"Times New Roman\",\n\
FontSize->14,\nFontWeight->\"Plain\"]\)\!\(\*\nStyleBox[\" \",\n\
FontFamily->\"Times New Roman\",\nFontSize->14,\nFontWeight->\"Plain\"]\)\!\(\
\*\nStyleBox[\"Lines\",\nFontFamily->\"Times New Roman\",\nFontSize->14,\n\
FontWeight->\"Plain\"]\)", {1, 2, 3, 4, 9, 10, 11, 12, 17, 18, 19, 20} -> 
            "\!\(\*\nStyleBox[\"P\",\nFontFamily->\"Times New Roman\",\n\
FontSize->14,\nFontWeight->\"Plain\"]\)\!\(\*\nStyleBox[\" \",\n\
FontFamily->\"Times New Roman\",\nFontSize->14,\nFontWeight->\"Plain\"]\)\!\(\
\*\nStyleBox[\"Lines\",\nFontFamily->\"Times New Roman\",\nFontSize->14,\n\
FontWeight->\"Plain\"]\)"}, Appearance -> ("Vertical" -> {Automatic, 8})]}], 
        Delimiter, 
        Style["C Lines Schl\[ADoubleDot]fli Double Six", 10], 
        Row[{
          TogglerBar[
           
           Dynamic[$CellContext`LinesOn], {{5, 13, 21, 7, 15, 23} -> 
            "First Sextuple", {6, 14, 22, 8, 16, 24} -> "Second Sextuple"}, 
           Appearance -> ("Vertical" -> {Automatic, 3})]}], 
        Delimiter, {{$CellContext`lineColoring$$, {
           RGBColor[1, 0, 0], 
           RGBColor[1, 0, 0], 
           RGBColor[1, 0, 0], 
           RGBColor[1, 0, 0], 
           RGBColor[1, 0, 0], 
           RGBColor[1, 0, 0], 
           RGBColor[1, 0, 0], 
           RGBColor[1, 0, 0], 
           RGBColor[0, 0, 1], 
           RGBColor[0, 0, 1], 
           RGBColor[0, 0, 1], 
           RGBColor[0, 0, 1], 
           RGBColor[0, 0, 1], 
           RGBColor[0, 0, 1], 
           RGBColor[0, 0, 1], 
           RGBColor[0, 0, 1], 
           RGBColor[0, 1, 0], 
           RGBColor[0, 1, 0], 
           RGBColor[0, 1, 0], 
           RGBColor[0, 1, 0], 
           RGBColor[0, 1, 0], 
           RGBColor[0, 1, 0], 
           RGBColor[0, 1, 0], 
           RGBColor[0, 1, 0]}, "Line Coloring Scheme"}, {{
            RGBColor[1, 0, 0], 
            RGBColor[1, 0, 0], 
            RGBColor[1, 0, 0], 
            RGBColor[1, 0, 0], 
            RGBColor[1, 0, 0], 
            RGBColor[1, 0, 0], 
            RGBColor[1, 0, 0], 
            RGBColor[1, 0, 0], 
            RGBColor[0, 0, 1], 
            RGBColor[0, 0, 1], 
            RGBColor[0, 0, 1], 
            RGBColor[0, 0, 1], 
            RGBColor[0, 0, 1], 
            RGBColor[0, 0, 1], 
            RGBColor[0, 0, 1], 
            RGBColor[0, 0, 1], 
            RGBColor[0, 1, 0], 
            RGBColor[0, 1, 0], 
            RGBColor[0, 1, 0], 
            RGBColor[0, 1, 0], 
            RGBColor[0, 1, 0], 
            RGBColor[0, 1, 0], 
            RGBColor[0, 1, 0], 
            RGBColor[0, 1, 0]} -> "XYZ Coloring", {
            RGBColor[1, 1, 0], 
            RGBColor[1, 1, 0], 
            RGBColor[1, 1, 0], 
            RGBColor[1, 1, 0], 
            RGBColor[1, 0, 1], 
            RGBColor[0, 1, 1], 
            RGBColor[1, 0, 1], 
            RGBColor[0, 1, 1], 
            RGBColor[1, 1, 0], 
            RGBColor[1, 1, 0], 
            RGBColor[1, 1, 0], 
            RGBColor[1, 1, 0], 
            RGBColor[1, 0, 1], 
            RGBColor[0, 1, 1], 
            RGBColor[1, 0, 1], 
            RGBColor[0, 1, 1], 
            RGBColor[1, 1, 0], 
            RGBColor[1, 1, 0], 
            RGBColor[1, 1, 0], 
            RGBColor[1, 1, 0], 
            RGBColor[1, 0, 1], 
            RGBColor[0, 1, 1], 
            RGBColor[1, 0, 1], 
            RGBColor[0, 1, 1]} -> "C Lines Schl\[ADoubleDot]fli Coloring"}}}, 
      "Options" :> {}, "DefaultOptions" :> {}],
     ImageSizeCache->{1287., {511., 519.}},
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    SynchronousInitialization->True,
    UndoTrackedVariables:>{Typeset`show$$, Typeset`bookmarkMode$$},
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Manipulate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Output",
 CellChangeTimes->{
  3.764323635259672*^9},ExpressionUUID->"b8842058-8ea9-4dc5-83c8-\
8a202ab05b9b"]
}, Open  ]]
}, Open  ]]
},
WindowSize->{1635, 892},
WindowMargins->{{Automatic, -1744}, {1, Automatic}},
Magnification:>1.5 Inherited,
FrontEndVersion->"11.1 for Mac OS X x86 (32-bit, 64-bit Kernel) (April 18, \
2017)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[580, 22, 304, 4, 220, "Title", "ExpressionUUID" -> \
"475d4fe8-64d7-41bc-9fa7-34e4277a5789"],
Cell[887, 28, 2029, 46, 384, "Input", "ExpressionUUID" -> \
"63976467-8147-4ef7-ae67-2bef6fd50011",
 InitializationCell->True],
Cell[CellGroupData[{
Cell[2941, 78, 39601, 937, 3670, "Input", "ExpressionUUID" -> \
"b6ff0f78-a0cb-4369-a0b9-bfe042eeab31"],
Cell[42545, 1017, 29952, 624, 1055, "Output", "ExpressionUUID" -> \
"b8842058-8ea9-4dc5-83c8-8a202ab05b9b"]
}, Open  ]]
}, Open  ]]
}
]
*)

